import setuptools

setuptools.setup(
    name="pytwwa5",
    version='1.0',
    packages = setuptools.find_packages(),
    install_requires = ['request'],
    description="Our first Python distribution package",
    author="Unknown",
    author_email = "unknown@gmail.com"
)
